Toc

Struct Toc 

pub struct Toc { /* private fields */ }
Table of contents.

Implementations

Source

impl Toc

pub fn from_read<T: Read>( reader: &mut T, _expected: usize, ) -> Result<Toc, Error>

Contstruct a toc from a reader pointed at the start of it.

pub fn data(&self) -> &Element

pub fn write<W: Write>(&self, writer: W) -> Result<(), Error>

Print the toc as XML to writer.

pub fn creation_time(&self) -> Result<NaiveDateTime, Error>

Compute creation time of Toc.

pub fn checksum_type(&self) -> Result<&String, Errors>

Get what type of checksum was used for the Toc.

pub fn checksum_offset(&self) -> Result<usize, Error>

Find out at which offset the checksum is.

pub fn checksum_size(&self) -> Result<usize, Error>

Find out how many bytes the checksum is.

pub fn files(&self) -> Result<Files<'_>, Errors>